@@ -7,7 +7,7 @@ use warnings FATAL => 'all';
 use English qw( -no_match_vars );
 local $OUTPUT_AUTOFLUSH = 1;
 
-our $VERSION = '0.21_16';
+our $VERSION = '0.21_17';
 $VERSION = eval $VERSION; # Comment out when we don't have a dev component, eg 0.21_15
 
 use utf8;
@@ -682,7 +682,7 @@ Debug::Client - debugger client side code for Padre, The Perl IDE.
 
 =head1 VERSION
 
-This document describes Debug::Client version 0.21_16
+This document describes Debug::Client version 0.21_17
 
 =head1 SYNOPSIS
 
@@ -724,11 +724,11 @@ Once the script under test was launched we can call the following:
 
   $debugger->execute_code( '@name = qw(foo bar)' );
 
-  my $value = $debugger->get_value('@name');  $value is the dumped data?
+  my $value = $debugger->get_value('@name'); # $value is the dumped data?
 
   $debugger->execute_code( '%phone_book = (foo => 123, bar => 456)' );
 
-  my $value = $debugger->get_value('%phone_book');  $value is the dumped data?
+  my $value = $debugger->get_value('%phone_book'); # $value is the dumped data?
   
   
   $debugger->set_breakpoint( "file", 23 ); # set breakpoint on file, line
@@ -768,7 +768,7 @@ This is a DEVELOPMENT Release only, you have been warned!
 
 The primary use of this module is to provide debugger functionality for Padre 0.97+, 
 
-This module has been tested against Perl 5.17.5.
+This module has been tested against Perl 5.17.8.
 
 =head1 METHODS
 
@@ -934,6 +934,8 @@ Output is pretty-printed in the same style as for V and the format is controlled
 
   $debugger->get_y_zero();
 
+which is now y=1 since perl 5.17.6, 
+
 =item get_v_vars
 
 V [pkg [vars]]
@@ -1057,7 +1059,7 @@ and just performing c on it's own
 
 I<Warning sub listen has bean deprecated>
 
-Has bean deprecated since 0.13_04 and all future version 0.21_16
+Has bean deprecated since 0.13_04 and all future version starting with v0.14
 
 Perl::Critic Error Subroutine name is a homonym for built-in function
 
